@@ -11,11 +11,11 @@ Perl::Critic::Bangs - A collection of handy Perl::Critic policies
 
 =head1 VERSION
 
-Version 1.00
+Version 1.07_01
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.07_01';
 
 =head1 SYNOPSIS
 
@@ -50,13 +50,13 @@ a cut-n-paste that is incorrect.
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitUselessRegexModifiers>
 
 Adding modifiers to a regular expression made up entirely of a
-variable created with qr() is usually not doing what you expect.
+variable created with C<qr()> is usually not doing what you expect.
 
 =head2 L<Perl::Critic::Policy::Bangs::ProhibitVagueNames>
 
 Vague variables like C<$data> or C<$info> are not descriptive enough.
 
-=head1 WHY BANGS?
+=head1 WHY IS IT CALLED Perl::Critic::Bangs?
 
 I didn't want to call it "Perl::Critic::Lester" or "Perl::Critic::Petdance"
 that would make it sound like they were only my rules.  Other people
@@ -106,9 +106,9 @@ L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Critic-Bangs>
 
 L<http://search.cpan.org/dist/Perl-Critic-Bangs>
 
-=item * Subversion repository
+=item * Source code repository
 
-L<http://perl-critic-bangs.googlecode.com/svn/>
+L<http://github.com/petdance/perl-critic-bangs>
 
 =back
 
@@ -122,14 +122,16 @@ Thanks to
 
 =item * Oystein Torget for bug reports and patches.
 
+=item * Elliot Shank and the rest of the Perl::Critic team for ongoing support.
+
 =back
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT & LICENSE
 
-Copyright 2006, 2007 Andy Lester, all rights reserved.
+Copyright 2006-2011 Andy Lester.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the Artistic License 2.0.
 
 =cut
 
