@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.00';
+our $VERSION = '1.07_01';
 
 #----------------------------------------------------------------------------
 
@@ -20,9 +20,9 @@ sub supported_parameters {
     );
 }
 
-sub default_severity     { return $SEVERITY_LOW           }
-sub default_themes       { return qw( bangs maintenance ) }
-sub applies_to           { return 'PPI::Token::Comment'   }
+sub default_severity     { return $SEVERITY_LOW                             }
+sub default_themes       { return qw( bangs maintenance )                   }
+sub applies_to           { return qw( PPI::Token::Comment PPI::Token::Pod ) }
 
 
 #---------------------------------------------------------------------------
@@ -84,11 +84,10 @@ Based on App::Fluff by Andy Lester, "<andy at petdance.com>"
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2008 Andy Lester <andy@petdance.com> and Andrew
-Moore <amoore@mooresystems.com>.  All rights reserved.
+Copyright (c) 2006-2011 Andy Lester <andy@petdance.com> and Andrew
+Moore <amoore@mooresystems.com>.
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.  The full text of this license
-can be found in the LICENSE file included with this module.
+This library is free software; you can redistribute it and/or modify
+it under the terms of the Artistic License 2.0.
 
 =cut
