@@ -5,7 +5,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.00';
+our $VERSION = '1.07_01';
 
 sub supported_parameters { return ()                     }
 sub default_severity     { return $SEVERITY_HIGH         }
@@ -22,7 +22,7 @@ sub violates {
     return if is_subroutine_name($elem);
 
     my $suspectproto = $elem->snext_sibling();
-    if ( $suspectproto->isa( 'PPI::Token::Symbol' ) ) {
+    if ( $suspectproto && $suspectproto->isa( 'PPI::Token::Symbol' ) ) {
         # $suspectproto is the thing I'm calling ref on. Let's see if there's a || after that.
         if ( $suspectproto->snext_sibling()
                 && $suspectproto->snext_sibling->isa( 'PPI::Token::Operator' )
@@ -31,8 +31,8 @@ sub violates {
             # this is where I test to see if the thing after the || is the same as the thing before the ref
             if ( $or->snext_sibling() eq $suspectproto->content() ) {
                 # here it looks like we have ref $proto || $proto
-                my $desc = q("ref $proto || $proto" construct found); ## no critic
-                my $expl = q(Probably cut-and-pasted example code);
+                my $desc = q{"ref $proto || $proto" construct found}; ## no critic (RequireInterpolationOfMetachars)
+                my $expl = q{Probably cut-and-pasted example code};
                 return $self->violation( $desc, $expl, $elem );
             }
         }
@@ -110,11 +110,9 @@ and work done by Andrew Moore <amoore@mooresystems.com>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2008 Andy Lester C<< <andy at petdance.com> >>.  All
-rights reserved.
+Copyright (C) 2006-2011 Andy Lester
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.  The full text of this license
-can be found in the LICENSE file included with this module.
+This library is free software; you can redistribute it and/or modify it
+under the terms of the Artistic License 2.0.
 
 =cut
